/* @override http://localhost:3210/static/css/appnav.css */

/* @override http://localhost:3000/static/css/appnav.css */



/* @group Explore */

div#appList {
	top: -17px;
	right: -5px;
	display: none;
}

div#appKitSearch {
	top: -17px;
	right: 115px;
	display: none;	
}

div.tlMenu {
	opacity: 1;
	Xfilter:alpha(opacity=1);
	position: absolute;
	z-index: 1;
	font-family: "Helvetica Neue", Helvetica, Arial, Geneva, sans-serif;	
}

div.tlMenu_top {
	filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='crop');
	background-image: url(../images/explore_tm.png);
	margin-right: 83px;
	margin-left: 11px;
	height: 27px;
}

div.tlMenu_tl {
	width: 11px;
	height: 27px;
	filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='crop');
	background-image: url(../images/explore_tl.png);
	position: absolute;
	top: 0;
	left: 0;
}

div.tlMenu_tr {
	width: 83px;
	height: 27px;
	filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='crop');
	background-image: url(../images/explore_tr.png);
	position: absolute;
	top: 0;
	right: 0;
}

div.tlMenu_mid {
	overflow: hidden;
}

div.tlMenu_ml {
	float: left;
	background-image: url(../images/explore_c.png);
	Xfilter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='crop');
}

div.tlMenu_mr {
	filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='crop');
	background-image: url(../images/explore_mr.png);
	width: 24px;
	float: left;
	padding-bottom: 2000px;
	margin-bottom: -2000px;
}

div.tlMenu_bot {
	height: 31px;
	margin-left: 26px;
	margin-right: 31px;
	background-image: url(../images/explore_bm.png);
	filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='crop');
	clear: both;
}

div.tlMenu_bl {
	width: 26px;
	height: 31px;
	filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='scale');
	background-image: url(../images/explore_bl.png);
	position: absolute;
	left: 0;
	bottom: 0;
}

div.tlMenu_br {
	width: 31px;
	height: 31px;
	filter: progid:DXImageTransform.Microsoft.AlphaImageLoader(src='../images/1x1.png', sizingMethod='scale');
	background-image: url(../images/explore_br.png);
	position: absolute;
	right: 0;
	bottom: 0;
}

/* @group Links */

/* @group Icons */



/* @end */

ul.appList_l1 {
	list-style-type: none;
	margin: 0;
	Xfloat: left;
	font-size: .9em;
	padding: 0 0 4px 17px;
	Xborder: 2px solid lime;
}

div.tlMenu_ml p {
	margin: 2px 16px 4px 17px;
	padding: 0 0 2px;
	border-bottom: 1px solid #515151;
	color: #cacaca;
	font-size: 0.8em;
}

ul.appList_l1 li {
	float: left;
	color: #e4e4e4;
	text-align: left;
	font-weight: bold;
	padding-right: 4px;
	padding-bottom: 0;
}

ul.appList_l1 li span.appList_heading {
	margin-bottom: 4px;
	display: block;
	padding-bottom: 3px;
	border-bottom: 1px solid #515151;
}

ul.appList_l2 {
	list-style-type: none;
	text-align: left;
	margin: 3px 12px 0 0;
	padding: 0;
}

ul.appList_l2 li {
	float: none;
	font-size: 0.9em;
	margin: 0;
	padding: 0;
	font-weight: 500;
	font-style: normal;
}

ul.appList_l2 li a {
	text-decoration: none;
	color: #e1e2e1;
	display: block;
	margin-bottom: 9px;
	margin-top: 5px;
	-moz-border-radius: 6px;
	-webkit-border-radius: 6px;
	border-radius: 6px;
	padding: 11px 11px 12px 38px;
	background-position: 0;
}

ul.appList_l2 li a:hover {
	color: #e0e0e0;
	background-color: rgba(202,202,202,0.18);
}

/* @end */

/* @end */

/* @group Mega menu */

div#application_home a {
	width: 35px;
	height: 42px;
	display: block;
	position: absolute;
	background: url(../images/icons/home-med.png) no-repeat 2px 7px;
	left: 15px;
	border-right: 1px solid #515151;
	padding-right: 10px;
	top: 6px;
}

#header {
    z-index: 4;
}

div#appMenuBar {
	position: absolute;
	top: 17px;
	left: 77px;
	width: 710px;
}

div#appMenuBar ul {
	margin: 0;
	padding: 0;
}

div#appMenuBar li {
	display: block;
}

div#appMenuBar li.appkit_mega_menu_item {
	position: relative;
	display: inline;
	margin-left: -5px;
}

div#appMenuBar li.appkit_mega_menu_item > a {
	margin: 0;
	padding: 17px 18px 18px;
	text-decoration: none;
	color: #e0e0e0;
}

div#appMenuBar li.appkit_mega_menu_item > a:hover {
	color: white;
}

li.appkit_mega_menu_item div.appkit_mega_menu_content {
	position: absolute;
	background-color: white;
    display: table;
    visibility: hidden;
	border: 0 solid silver;
	top: 36px;
	padding-left: 17px;
	padding-top: 15px;
	padding-bottom: 19px;
	-moz-box-shadow: 3px 3px 5px #888;
    -webkit-box-shadow: 3px 3px 5px #888;
    box-shadow: 3px 3px 5px #888;
	color: #222;
}

li.appkit_mega_menu_open > a {
	background-color: #555;
}

ul.appkit_mega_menu li.appkit_mega_menu_item.appkit_mega_menu_open div.appkit_mega_menu_content div div.appkit_mega_menu_group p {
	font-size: 100%;
	margin: 0 0 4px;
	border-bottom: 2px solid silver;
	padding-right: 10px;
}

div.appkit_mega_menu_group:not(:first-child) {
	padding-top: 12px;
}

div.appkit_mega_menu_group p:not(:first-child) {
	padding-top: 12px;
}

li.appkit_mega_menu_open div.appkit_mega_menu_content {
	display: table;
    *display: block;
    visibility: visible;
	z-index: 10;
}

li.appkit_mega_menu_open div.appkit_mega_menu_content a {
	z-index: 11;
	padding-right: 10px;
}

div.appkit_mega_menu_group {
	margin-right: 20px;
}

.appkit_mega_menu_content {
    width: 600px; /* default to be overriden */
    left: 0;
}

/* @end */

/* @group App-style search */

li#appkit_app_style_search {
	Xbackground: url(../images/icons/search-med.png) no-repeat 2px 11px;
	padding-top: 13px;
}

li#appkit_app_style_search input {
	background-color: #eee;
	border: 2px solid #eee;
	margin-right: 2px;
	margin-left: 17px;
	width: 140px;
	font-size: 1em;
}

.application_style li#appkit_app_style_search input {
	font-size: 1em;
}

li#appkit_app_style_search input:focus {
	background-color: white;
}

div.menu_column {
    float: left;
};

/* @end */
