package OpusVL::AppKit::Model::AppKitAuthDB;

use strict;
use base 'Catalyst::Model::DBIC::Schema';

__PACKAGE__->config(
    schema_class => 'OpusVL::AppKit::Schema::AppKitAuthDB',
    
    connect_info => {
        dsn => 'dbi:SQLite:./t/lib/auto/TestApp/root/db/appkit_auth.db',
        user => '',
        password => '',
    }
);

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

OpusVL::AppKit::Model::AppKitAuthDB

=head1 VERSION

version 2.20

=head1 SYNOPSIS

See L<OpusVL::AppKit>

=head1 DESCRIPTION

L<Catalyst::Model::DBIC::Schema> Model using schema L<OpusVL::AppKit::Schema::AppKitAuthDB>

=head1 NAME

OpusVL::AppKit::Model::AppKitAuthDB - Catalyst DBIC Schema Model

=head1 GENERATED BY

Catalyst::Helper::Model::DBIC::Schema - 0.38

=head1 AUTHOR

OpusVL - www.opusvl.com

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by OpusVL - www.opusvl.com.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
